# python-cmk

[![GitHub](https://img.shields.io/github/license/NimVek/python-cmk)](https://github.com/NimVek/python-cmk/blob/main/LICENSE)
[![Code style: black](https://img.shields.io/badge/code%20style-black-black)](https://github.com/psf/black)
[![Build Status](https://img.shields.io/github/workflow/status/NimVek/python-cmk/Continuous%20Integration)](https://github.com/NimVek/python-cmk/actions/)
[![Coverage Status](https://img.shields.io/codecov/c/github/NimVek/python-cmk)](https://codecov.io/gh/NimVek/python-cmk/)
[![Documentation](https://img.shields.io/badge/docs-passing-brightgreen)](https://nimvek.github.io/python-cmk/)
[![GitHub last commit](https://img.shields.io/github/last-commit/NimVek/python-cmk)](https://github.com/NimVek/python-cmk/commits/main)

API for CheckMK
